@@ -10,7 +10,6 @@
 #include "collectionindexer.h"
 #include "xapiandocument.h"
 
-#include <QString>
 #include <QStringList>
 #include <AkonadiCore/collectionidentificationattribute.h>
 #include <AkonadiCore/AttributeFactory>
@@ -22,7 +21,7 @@ CollectionIndexer::CollectionIndexer(const QString &path)
     Akonadi::AttributeFactory::registerAttribute<Akonadi::CollectionIdentificationAttribute>();
 
     try {
-        m_db = new Xapian::WritableDatabase(path.toUtf8().constData(), Xapian::DB_CREATE_OR_OPEN);
+        m_db = new Xapian::WritableDatabase(path.toStdString(), Xapian::DB_CREATE_OR_OPEN);
     } catch (const Xapian::DatabaseCorruptError &err) {
         qCCritical(AKONADI_INDEXER_AGENT_LOG) << "Database Corrupted - What did you do?";
         qCCritical(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
@@ -41,8 +40,7 @@ CollectionIndexer::~CollectionIndexer()
 
 static QByteArray getPath(const Akonadi::Collection &collection)
 {
-    QStringList pathParts;
-    pathParts << collection.displayName();
+    QStringList pathParts = {collection.displayName()};
     Akonadi::Collection col = collection;
     while (col.parentCollection().isValid() && (col.parentCollection() != Akonadi::Collection::root())) {
         col = col.parentCollection();
@@ -64,8 +62,8 @@ void CollectionIndexer::index(const Akonadi::Collection &collection)
         gen.set_document(doc);
         gen.set_database(*m_db);
 
-        gen.index_text_without_positions(collection.displayName().toUtf8().constData());
-        gen.index_text_without_positions(collection.displayName().toUtf8().constData(), 1, "N");
+        gen.index_text_without_positions(collection.displayName().toStdString());
+        gen.index_text_without_positions(collection.displayName().toStdString(), 1, "N");
 
         //We index with positions so we can do phrase searches (required for exact matches)
         {
@@ -75,12 +73,12 @@ void CollectionIndexer::index(const Akonadi::Collection &collection)
             doc.add_term(term.constData());
         }
 
-        Akonadi::Collection::Id colId = collection.parentCollection().id();
+        const Akonadi::Collection::Id colId = collection.parentCollection().id();
         const QByteArray term = 'C' + QByteArray::number(colId);
         doc.add_boolean_term(term.constData());
 
         QByteArray ns;
-        if (const Akonadi::CollectionIdentificationAttribute *folderAttribute = collection.attribute<Akonadi::CollectionIdentificationAttribute>()) {
+        if (const auto *folderAttribute = collection.attribute<Akonadi::CollectionIdentificationAttribute>()) {
             if (!folderAttribute->collectionNamespace().isEmpty()) {
                 ns = folderAttribute->collectionNamespace();
             }
@@ -150,7 +148,14 @@ void CollectionIndexer::move(const Akonadi::Collection &collection, const Akonad
 
 void CollectionIndexer::commit()
 {
-    if (m_db) {
-        m_db->commit();
+    if (!m_db) {
+        return;
     }
+
+    try {
+        m_db->commit();
+    } catch (const Xapian::Error &err) {
+        qCWarning(AKONADI_INDEXER_AGENT_LOG) << err.get_error_string();
+    }
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Xapian Committed";
 }
